local revision = tonumber(("$Revision: 62698 $"):match("%d+"))
if not NSD_REVISION or revision > NSD_REVISION then
    NSD_REVISION = revision
    NSD_DATE = ("$Date: 2008-02-23 18:22:38 -0500 (Sat, 23 Feb 2008) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

-- localisations
local L = Rock("LibRockLocale-1.0"):GetTranslationNamespace("ShakedownDBM")
L:AddTranslations("enUS", function() return {
    ["Deadly Boss Mods"] = true,
    ["Raid Warning"] = true,
    ["Local Warning"] = true,
} end)

local Addon = AddonBase:new("DBM_GUI", L["Deadly Boss Mods"])
if not Addon then return end

-- constants
local TIMER_BAR_FREQ = 21
local TIMER_BAR_ID = "DBMBarShakedown"
local TIMER_MSG_FREQ = 2
local TIMER_MSG_ID = "DBMMsgShakedown"

-- members
Addon.RWdeltaX = 0
Addon.RWdeltaY = 0
Addon.SWdeltaX = 0
Addon.SWdeltaY = 0

function Addon:Start()
    
    -- show a message now
    self:ShowMessage()
    
    -- show bar now
    self:ShowBar()

    --schedule repeating messages and bars
    NShakedown:AddRepeatingTimer(TIMER_MSG_ID, TIMER_MSG_FREQ, self.ShowMessage, self)
    NShakedown:AddRepeatingTimer(TIMER_BAR_ID, TIMER_BAR_FREQ, self.ShowBar, self)
    
    -- show the distance frame
    if not DBMDistanceFrame or not DBMDistanceFrame:GetObject():IsShown() then
        DBM_Gui_DistanceFrame()
    end

    -- make the warning frames draggable
    self:MakeDraggable(RaidWarningFrame)
    self:MakeDraggable(DBMWarningFrame)
    
    -- calculate the co-ord delta between that which we get from GetPoint and the top centre aligned co-ords that DBM works with for raid warning
    RaidWarningFrame:StartMoving()
    RaidWarningFrame:StopMovingOrSizing()
    local _, _, _, x, y = RaidWarningFrame:GetPoint()
    self.RWdeltaX = DBM.Options.Gui.RaidWarning_PosX - x
    self.RWdeltaY = DBM.Options.Gui.RaidWarning_PosY - y
    
    -- calculate the co-ord delta between that which we get from GetPoint and the bottom centre aligned co-ords that DBM works with for raid warning
    DBMWarningFrame:StartMoving()
    DBMWarningFrame:StopMovingOrSizing()
    local _, _, _, x, y = DBMWarningFrame:GetPoint()
    self.SWdeltaX = DBM.Options.Gui.SelfWarning_PosX - x
    self.SWdeltaY = DBM.Options.Gui.SelfWarning_PosY - y
end

function Addon:Stop()

    -- check existence
    if not DBMGUI_VERSION then return end
    
    -- hide the dragbar
    DBM_StatusBarTimerDrag:Hide()
    DBM_StatusBarTimerDrag2:Hide()
        
    -- hide the distance frame
    DBM_Gui_DistanceFrame()

    -- remove the draggable raid warning frames
    self:MakeUnDraggable(RaidWarningFrame)
    self:MakeUnDraggable(DBMWarningFrame)
    
    -- kill the scheduled messages and bars
    NShakedown:RemoveTimer(TIMER_BAR_ID)
    NShakedown:RemoveTimer(TIMER_MSG_ID)

end

function Addon:ShowMessage()

    RaidWarningFrames_AddLocalMessages(DBMGUI_RAIDWARNING_EXAMPLE)
    DBM.HasAggro(L["Deadly Boss Mods"])
    
end

function Addon:ShowBar()

    DBM_StatusBarTimerDrag:Show()
    DBM_StatusBarTimerDrag2:Show()
    
end

function Addon:DragStart(this)

    this.isDragging = true
	this:StartMoving()
end

function Addon:DragStop(this)

    this:StopMovingOrSizing()
    this.isDragging = false
    
    local frameName = this:GetName()
    local _, _, _, x, y = this:GetPoint()
    if frameName == "RaidWarningFrame" then
        DBM.Options.Gui.RaidWarning_PosX = x + self.RWdeltaX
        DBM.Options.Gui.RaidWarning_PosY = y + self.RWdeltaY
    elseif frameName == "DBMWarningFrame" then
        DBM.Options.Gui.SelfWarning_PosX = x + self.SWdeltaX
        DBM.Options.Gui.SelfWarning_PosY = y + self.SWdeltaY
    end                                 
    
end

function Addon:MakeDraggable(frame)
    
    frame:SetBackdrop({ bgFile = self.backdropMayDrag, })
    frame:EnableMouse(true)
    frame:SetMovable(true)
    frame:RegisterForDrag("LeftButton")
    frame:SetScript("OnDragStart", function(this) self:DragStart(this) end)
	frame:SetScript("OnDragStop", function(this) self:DragStop(this) end)
    
end

function Addon:MakeUnDraggable(frame)
    
    frame:SetBackdrop({})
    frame:EnableMouse(false)
    frame:SetMovable(false)
    
end
